import React from 'react';
import { View, TouchableOpacity, TextInput } from 'react-native';
import PropTypes from 'prop-types';

export default class InputText extends TextInput
{
    constructor (props)
    {
        super (props);

        this.state = {
            isFocused: false,
        };

        this.onFocus = this.onFocusEvent.bind (this);
        this.onBlur = this.onBlurEvent.bind (this);
        
        this.refEvent = this.onRefEvent.bind (this);
    }

    onFocusEvent ()
    {
        this.setState ({ isFocused: true });
        if (this.props.onFocus)
        {
            this.props.onFocus ();
        }
    }

    onRefEvent (ref)
    {
        this.textInput = ref;
        if (this.props.ref)
        {
            this.props.ref (ref);
        }
    }

    onBlurEvent ()
    {
        this.setState ({ isFocused: false });
        if (this.props.onBlur)
        {
            this.props.onBlur ();
        }
    }

    render ()
    {
        return (
            <View style={[{ backgroundColor: 'transparent' }, this.props.containerStyle]}>
                <TextInput
                    {...this.props}
                    onFocus={this.onFocus}
                    onBlur={this.onBlur}
                    ref={this.refEvent}
                >
                    {this.props.children}
                </TextInput>
                {!this.state.isFocused &&
                    <TouchableOpacity
                        activeOpacity={6}
                        style={{ position: 'absolute', top: 0, bottom: 0, left: 0, right: 0, }}
                        onPress={() => this.textInput.focus ()}
                        disabled={!this.props.editable}
                    />
                }
            </View>
        );
    }
}

InputText.propTypes = {
    containerStyle: PropTypes.object,
    editable: PropTypes.bool
};

InputText.defaultProps = {
    containerStyle: {},
    editable: true
};
